@@ -185,8 +185,8 @@ class Links(BaseModel):
     receipt: Receipt
     notify: Optional[List[Notify]]
     update: Update
-    confirm: Confirm
-    cancel: Cancel
+    confirm: Confirm = Confirm(**{'url': None, 'last_opened_at': None, 'method': None})
+    cancel: Cancel = Cancel(**{'url': None, 'last_opened_at': None, 'method': None})
 
     class Config:
         validate_all = True
