@@ -25,6 +25,7 @@ from oc_python_sdk.models.payment import (
 from ._helpers import (
     get_empty_notify_data,
     get_links_data,
+    get_links_data_without_cancel_and_confirm,
     get_notify_data,
     get_online_payment_begin_data,
     get_payer_data,
@@ -144,6 +145,7 @@ class PaymentTestCase(TestCase):
         notify_no_data = Notify(**get_empty_notify_data())
         update = Update(**get_update_data())
         links = Links(**get_links_data())
+        links_without_cancel_and_confirm = Links(**get_links_data_without_cancel_and_confirm())
         payer = Payer(**get_payer_data())
 
         self.assertEqual(json.loads(payment.json())['id'], 'bb7044e4-066c-4bf7-915e-87ee97270eae')
@@ -194,6 +196,10 @@ class PaymentTestCase(TestCase):
         self.assertEqual(json.loads(notify_no_data.json()), {'url': None, 'method': None, 'sent_at': None})
         self.assertEqual(json.loads(update.json())['url'], None)
         self.assertEqual(len(json.loads(links.json())['notify']), 1)
+        self.assertEqual(
+            json.loads(links_without_cancel_and_confirm.json())['cancel'],
+            {'url': None, 'method': None, 'last_opened_at': None},
+        )
         self.assertEqual(json.loads(payer.json())['type'], PayerType.TYPE_HUMAN.value)
         with self.assertRaises(ValidationError):
             PaymentData(**get_payment_data(split=None))
